@@ -194,8 +194,9 @@ class SSHClient(object):
         log.info(f" {self.__ip}:{self.__port} | begin to run cmd:{cmd}.")
         try:
             if promt_response:
-                channel = self.__ssh.get_transport().open_session()
-                channel.get_pty()  # 获取虚拟终端
+                channel = self.__ssh.exec_command('bash', get_pty=True)[0].channel
+                # channel = self.__ssh.get_transport().open_session()
+                # channel.get_pty()  # 获取虚拟终端
                 channel.exec_command(cmd)
                 output = ""
                 begin=datetime.now()
